# pptitles

Extract the slide number and title from all slides in a PowerPoint presentation.

## Installation

```
git clone https://github.com/phx/pptitles
cd pptitles
python3 -m pip install -r requirements.txt
sudo mv pptitles /usr/local/bin/
```

## Usage:

`pptitles "/path/to/presentation.pptx"`
